@@ -10,11 +10,11 @@ Varnish::CLI - An interface to the Varnish CLI
 
 =head1 VERSION
 
-Version 0.03
+Version::CLI 0.01
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.01';
 
 
 =head1 SYNOPSIS
@@ -43,40 +43,40 @@ Remember - complete contents of the secret file (including a newline if it exist
     
 =head1 PROPERTIES
 
-    has host =>        ( is       => 'ro',
-                         isa      => 'Str',
-                         required => 1,
-                         default  => 'localhost' );
+has host =>        ( is       => 'ro',
+                     isa      => 'Str',
+                     required => 1,
+                     default  => 'localhost' );
 
-    has port =>        ( is       => 'ro',
-                         isa      => 'Int',
-                         required => 1,
-                         default  => 6082 );
+has port =>        ( is       => 'ro',
+                     isa      => 'Int',
+                     required => 1,
+                     default  => 6082 );
 
-    has timeout =>     ( is       => 'rw',
-                         isa      => 'Int',
-                         required => 1,
-                         default  => 1 );
+has timeout =>     ( is       => 'rw',
+                     isa      => 'Int',
+                     required => 1,
+                     default  => 1 );
 
-    has t =>           ( is       => 'rw',
-                         isa      => 'Net::Telnet',
-                         clearer  => 'clear_t' );
+has t =>           ( is       => 'rw',
+                     isa      => 'Net::Telnet',
+                     clearer  => 'clear_t' );
                 
-    has secret =>      ( is       => 'rw',
-                         isa      => 'Str' );
+has secret =>      ( is       => 'rw',
+                     isa      => 'Str' );
 
-    has connected =>   ( is       => 'rw',
-                         isa      => 'Int',
-                         default  => 0,
-                         required => 1 );
+has connected =>   ( is       => 'rw',
+                     isa      => 'Int',
+                     default  => 0,
+                     required => 1 );
 
-    has last_lines =>  ( is       => 'rw',
-                         isa      => 'ArrayRef',
-                         default  => sub{ [] } );
+has last_lines =>  ( is       => 'rw',
+                     isa      => 'ArrayRef',
+                     default  => sub{ [] } );
 
-    has last_status => ( is       => 'rw',
-                         isa      => 'Int',
-                        );
+has last_status => ( is       => 'rw',
+                     isa      => 'Int',
+                    );
 
 =cut
 has host =>        ( is       => 'ro',
@@ -241,16 +241,13 @@ automatically be notified of progress on your bug as I make changes.
 
 You can find documentation for this module with the perldoc command.
 
-    perldoc Varnish::CLI
+    perldoc Varnish
+
 
 You can also look for information at:
 
 =over 4
 
-=item * Repository on Github
-
-L<https://github.com/robin13/Varnish-CLI>
-
 =item * RT: CPAN's request tracker
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Varnish>
@@ -272,7 +269,6 @@ L<http://search.cpan.org/dist/Varnish/>
 
 =head1 ACKNOWLEDGEMENTS
 
-L<http://www.varnish-cache.org/>
 
 =head1 LICENSE AND COPYRIGHT
 
